@@ -6,6 +6,56 @@ import distfit
 # print(distfit.__version__)
 # print(dir(distfit))
 
+from distfit import distfit
+X = np.random.normal(163, 10, 1000)
+dfit = distfit(multtest='test')
+dfit.fit_transform(X, n_boots=0)
+dfit.plot_summary()
+
+
+# %%
+
+from distfit import distfit
+X = np.random.normal(6, 1, 500)
+dfit = distfit()
+dfit.fit_transform(X)
+
+X2 = np.random.normal(6, 0.9, 500)
+X2 = np.hstack([[7]*50, X2])
+dfit2 = distfit()
+dfit2.fit_transform(X2)
+
+fig, ax = plt.subplots(1,2, figsize=(25,10))
+dfit.plot(title='without swear words', ax=ax[0])
+dfit2.plot(title='with swear words', ax=ax[1])
+
+import scipy.stats as st
+st.kstest(X, X2)
+
+# %% lineplot
+from distfit import distfit
+X = np.random.normal(163, 10, 1000)
+dfit = distfit(multtest='test')
+dfit.fit_transform(X, n_boots=10)
+dfit.plot_summary()
+dfit.plot_summary(ylim=[0, 0.0002])
+
+dfit.lineplot(X)
+
+y = [135, 145, 150, 160, 180, 185, 200]
+results = dfit.predict(y, multtest='holm')
+dfit.lineplot(X)
+
+# %% Import example
+
+from distfit import distfit
+dfit = distfit()
+df = dfit.import_example(data='gas_spot_price')
+dfit.lineplot(df, xlabel='Years', ylabel='Natural gas spot price', grid=True)
+plt.show()
+
+
+
 # %% CDF plot
 from distfit import distfit
 
@@ -13,19 +63,22 @@ from distfit import distfit
 # X = np.random.exponential(0.5, 10000)
 # X = np.random.uniform(0, 1000, 10000)
 X = np.random.normal(163, 10, 10000)
-dfit = distfit(distr='popular', n_boots=10, verbose='info')
-# Fit and plot
+# Initialize with bootstrapping
+dfit = distfit(n_boots=10)
+# Fit
 results = dfit.fit_transform(X)
+# Results
 dfit.summary[['name', 'score', 'bootstrap_score', 'bootstrap_pass']]
+# Plot
+dfit.plot_summary()
 
 
 out = dfit.bootstrap(X, n_boots=10, n_top=None)
-
 dfit.plot_summary()
 
 fig, ax = dfit.plot(chart='PDF', n_top=5, cmap='Set2');
 dfit.plot(chart='CDF', n_top=10, cmap='Set2', ax=ax);
-# dfit.plot_cdf()
+dfit.plot_cdf()
 
 
 # %%
@@ -51,16 +104,6 @@ dfit.plot(chart='CDF', n_top=5)
 dfit.plot(chart='CDF', pdf_properties=None, n_top=2)
 dfit.plot_cdf()
 
-# %%
-from distfit import distfit
-
-dfit = distfit(method='parametric', todf=True)
-dfit.load(r'c:\temp\model.pkl')
-dfit.plot(chart='PDF')
-
-dfit.plot(chart='PDF', emp_properties=None, pdf_properties=None, bar_properties=None)
-dfit.qqplot(X)
-
 # %% QQ plot
 from distfit import distfit
 dfit = distfit(verbose=20)
@@ -131,7 +174,7 @@ results = dfit.fit_transform(X)
 y = [0, 1, 10, 11, 12]
 
 results = dfit.predict(y)
-dfit.plot()
+dfit.plot(fontsize=14)
 
 # %%
 from distfit import distfit
@@ -293,7 +336,7 @@ dfit = distfit(stats='ks', distr=['k','t','expon', 'gamma', 'lognorm'], bins=50)
 results = dfit.fit_transform(X, verbose=0)
 
 dfit.plot()
-dfit.plot_summary()
+dfit.plot_summary(fontsize=10)
 
 # %% Multiple distributions as input
 import scipy.stats as st
